<template>
  <div class="page">
    <div class="info">
      <div class="detail" v-if="station.isProprietor">
        <span class="label">所属内保单位：</span>
        <span class="value">{{ station.proprietorCompanyName }}</span>
      </div>
      <div class="detail">
        <span class="label">公司名称：</span>
        <span class="value value-link" @click="toCompany">{{
          station.companyName + (station.institutional === "0104" ? "/自招" : "")
        }}</span>
      </div>
      <div v-if="stationType === 'TemporarySecurity'" class="detail">
        <span class="label">岗点名称：</span>
        <span class="value">{{ station.name }}</span>
      </div>
      <div class="detail">
        <span class="label">负责人员：</span>
        <span class="value">{{ station.principalName }}</span>
      </div>
      <div class="detail">
        <span class="label">联系方式：</span>
        <span v-if="!concatVisible" class="value">{{ station.contactHide }}</span>
        <span v-if="concatVisible" class="value">{{ station.principalContact }}</span>
        <span class="visible" @click="concatVisible = !concatVisible">{{ contactVisibleName }}</span>
      </div>
      <div class="detail" v-if="station.isSecurity">
        <span class="label">服务对象名称：</span>
        <span class="value">{{ station.serviceScope }}</span>
      </div>
      <div v-if="stationType === 'TemporarySecurity'" class="detail">
        <span class="label">所属临保项目：</span>
        <span class="value">{{ station.projectName }}</span>
      </div>
      <div class="detail">
        <span class="label">{{ stationTypeName }}监管机构：</span>
        <span class="value">{{ station.superviseDepartName }}</span>
      </div>
      <div class="detail">
        <span class="label">{{ stationTypeName }}地址：</span>
        <span class="value">{{ station.address }}</span>
      </div>
      <div class="detail" v-if="station.isSecurity">
        <span v-if="stationType === 'TemporarySecurity'" class="label">岗点类型：</span>
        <span v-if="stationType === 'TemporarySecurity'" class="value">{{ getStationTypesName(station.stationTypes) }}</span>
        <span v-if="stationType === 'Security'" class="label">驻勤点类型：</span>
        <span v-if="stationType === 'Security'" class="value">{{ station.stationTypeName }}</span>
      </div>
      <van-button type="info" block @click="clickStationEmployees">
        查看{{ securityMenType }}人员({{ station.countOfSecurityMan }})
      </van-button>
    </div>
  </div>
</template>

<script>
import { mapActions, mapState } from "vuex";
import { Button } from "vant";
import { getStationDetail } from "@/api/security-station-controller";
import { textSlice } from "@/api/common";
import { findInArray } from "@/utils";

export default {
  name: "StationInfo",
  components: {
    [Button.name]: Button,
  },
  data() {
    return {
      station: {},
      resourceTypeMap: {
        Security: "驻勤点",
        Population: "社区警务",
        TemporarySecurity: "临保岗点",
      },
      concatVisible: false,
    };
  },
  computed: {
    ...mapState({
      allStationTypes: (state) => state.app.stationTypes,
    }),
    contactVisibleName() {
      return this.concatVisible ? "隐藏" : "显示";
    },
    queryId() {
      return this.$route.query.queryId;
    },
    stationType() {
      return this.$route.query.type;
    },
    stationTypeName() {
      return this.resourceTypeMap[this.$route.query.type];
    },
    securityMenType() {
      //         查看{{ station.isSecurity ? "驻勤点" : "社区警务" }}人员({{ station.countOfSecurityMan }})
      if (this.station?.isSecurity) {
        if (this.$route.query.type === "Security") {
          return "驻勤点";
        } else {
          return "执勤点";
        }
      } else {
        return "社区警务";
      }
    },
  },
  watch: {
    queryId: {
      handler(newVal, OldVal) {
        if (newVal && newVal !== OldVal) {
          this.toStation();
        }
      },
      immediate: true,
    },
  },
  methods: {
    ...mapActions(["setAllStationTypes"]),
    /**
     * @驻勤点详情
     */
    toStation() {
      getStationDetail(this.queryId)
        .then((station) => {
          console.log(station);
          const { companyName, name, superviseDepartName, address, stationTypes, principalContact, resourceTypes } = station;
          this.station = {
            ...{
              companyNameSlice: textSlice(companyName),
              securityStationNameSlice: textSlice(name),
              superviseDepartNameSlice: textSlice(superviseDepartName),
              addressSlice: textSlice(address),
              stationTypeName: stationTypes[0]?.name,
              contactHide: this.parseStringToStar(principalContact),
              isSecurity: resourceTypes.includes("Security"),
              isProprietor: resourceTypes.includes("ProprietorManaged"),
            },
            ...station,
          };
        })
        .catch((err) => {
          console.log(err);
        });
    },
    parseStringToStar() {
      return "**************";
      // return str.length > 2 ? str.substr(0, 2) + new Array(str.length - 2).join("*") + str.substr(-2) : str;
    },
    toCompany() {
      this.$router.push({
        path: "/companyInfo",
        query: {
          queryId: this.station.organizationId,
        },
      });
    },
    /**
     * @点击驻勤点人员
     */
    clickStationEmployees() {
      let path = "/stationEmployees";
      if (this.securityMenType === "执勤点") path = "/tempStationEmployees";
      this.$router.push({
        path: path,
        query: {
          stationId: this.station.id,
          stationType: this.$route.query.type,
        },
      });
    },
    getStationTypesName(stationTypes) {
      if (!stationTypes || stationTypes.length <= 0) return "";
      if (this.allStationTypes.length <= 0) return "";
      let stationTypesName = "";
      const stationsCodes = stationTypes.map((x) => x.code);
      const allStations = findInArray(this.allStationTypes, stationsCodes, "code");
      if (allStations && allStations.length > 0) {
        stationTypesName = allStations.map((x) => x.name).join(",");
      }
      return stationTypesName;
    },
  },
  created() {
    this.setAllStationTypes();
  },
};
</script>

<style scoped lang="less">
.page {
  .info {
    width: 100%;
    padding: 12px 20px;
    box-sizing: border-box;
    .detail {
      width: 100%;
      display: flex;
      align-items: center;
      margin-bottom: 10px;
      &:last-child {
        margin-bottom: 0;
      }
      .label {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #909399;
      }

      .value {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #303133;
        &-link {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #0f71ff;
          text-decoration: underline;
        }
      }
      .visible {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #0f71ff;
        margin-left: 2px;
      }
    }
  }
}
</style>
